:mod:`mongo_client` -- Connecting to MongoLab
---------------------------------------------

.. automodule:: pymongolab.mongo_client
    :synopsis: Connecting to MongoLab
    :members:
    :undoc-members:
    :show-inheritance:
